@@ -184,7 +184,7 @@ gconf_engine_is_local(GConfEngine* conf)
  */
 
 GConfEngine*
-gconf_engine_new_local      (const gchar* address,
+gconf_engine_get_local      (const gchar* address,
                              GConfError** err)
 {
   GConfEnginePrivate* priv;
@@ -202,23 +202,33 @@ gconf_engine_new_local      (const gchar* address,
 
   priv->local_sources = gconf_sources_new_from_source(source);
 
+  g_assert (gconf_engine_is_local ((GConfEngine*)priv));
+  
   return (GConfEngine*)priv;
 }
 
 GConfEngine*
-gconf_engine_new            (void)
+gconf_engine_get_default            (void)
 {
   GConfEnginePrivate* priv;
 
-  priv = gconf_engine_blank(TRUE);
+  priv = lookup_engine (ConfigServer_default_context);
 
-  register_engine(priv);
+  if (priv == NULL)
+    {
+      priv = gconf_engine_blank(TRUE);
+      
+      register_engine(priv);
+    }
+  else
+    priv->refcount += 1;
 
+  
   return (GConfEngine*)priv;
 }
 
 GConfEngine*
-gconf_engine_new_from_address(const gchar* address, GConfError** err)
+gconf_engine_get_for_address(const gchar* address, GConfError** err)
 {
   GConfEngine* gconf;
   GConfEnginePrivate* priv;
@@ -238,8 +248,8 @@ gconf_engine_new_from_address(const gchar* address, GConfError** err)
   if (cs == CORBA_OBJECT_NIL)
     return NULL; /* Error should already be set */
   
-  ctx = ConfigServer_get_context(cs, (gchar*)address, &ev);
-
+  ctx = ConfigServer_get_context(cs, (gchar*)address, &ev);  
+  
   if (gconf_server_broken(&ev))
     {
       if (tries < MAX_RETRIES)
@@ -263,14 +273,21 @@ gconf_engine_new_from_address(const gchar* address, GConfError** err)
 
       return NULL;
     }
-  
-  priv = gconf_engine_blank(TRUE);
-  
+
+  priv = lookup_engine (ctx);
+
+  if (priv == NULL)
+    {
+      priv = gconf_engine_blank(TRUE);
+
+      priv->context = ctx;
+
+      register_engine(priv);
+    }
+  else
+    priv->refcount += 1;
+
   gconf = (GConfEngine*)priv;
-
-  priv->context = ctx;
-
-  register_engine(priv);
   
   return gconf;
 }
@@ -1763,7 +1780,18 @@ gconf_valid_key      (const gchar* key, gchar** why_invalid)
 gboolean
 gconf_key_is_below   (const gchar* above, const gchar* below)
 {
-  return strncmp(below, above, strlen(above)) == 0;
+  int len = strlen(above);
+  if (strncmp(below, above, len) == 0)
+    {
+      /* only if this is a complete key component,
+       * so that /foo is not above /foofoo/bar */
+      if (below[len] == '\0' || below[len] == '/')
+        return TRUE;
+      else
+	return FALSE;
+    }
+  else
+    return FALSE;
 }
 
 gchar*
@@ -2658,7 +2686,8 @@ register_engine(GConfEnginePrivate* priv)
 static GConfEnginePrivate*
 lookup_engine(ConfigServer_Context context)
 {
-  g_return_val_if_fail(context_to_engine_hash != NULL, NULL);
+  if (context_to_engine_hash == NULL)
+    return NULL;
 
   return g_hash_table_lookup(context_to_engine_hash, &context);
 }
